package server

import (
	"flag"
	"fmt"
	"github.com/charmbracelet/log"
	"net/http"
	"os"

	"git.smsvc.net/pomodoro/GoTomato/internal/metadata"
	"git.smsvc.net/pomodoro/GoTomato/internal/shared"
	"git.smsvc.net/pomodoro/GoTomato/internal/websocket"
	"git.smsvc.net/pomodoro/GoTomato/pkg/models"
)

var (
	// Define CLI flags
	listenAddress   = flag.String("listenAddress", shared.DefaultServerConfig.ListenAddress, "IP address to listen on")
	listenPort      = flag.Int("listenPort", shared.DefaultServerConfig.ListenPort, "Port to listen on")
	password        = flag.String("password", "", "Control password for pomodoro session (optional)")
	showVersionFlag = flag.Bool("version", false, "Output version")
)

func Start() {
	flag.Parse()

	if *showVersionFlag {
		fmt.Println("App-Version:", metadata.GoTomatoVersion)
		fmt.Println("Protocol-Version:", metadata.ProtocolVersion)
		os.Exit(0)
	}

	serverConfig := models.ServerConfig{
		ListenAddress: *listenAddress,
		ListenPort:    *listenPort,
	}
	shared.PomodoroPassword = *password

	listen := fmt.Sprintf("%s:%d", serverConfig.ListenAddress, serverConfig.ListenPort)

	http.HandleFunc("/ws", websocket.HandleConnections)
	go websocket.SendPermanentBroadCastMessage()

	log.Info("GoTomato started", "version", metadata.GoTomatoVersion)
	log.Info("Websocket listening", "address", listen)
	err := http.ListenAndServe(listen, nil)
	if err != nil {
		log.Fatal("Error starting server:", "msg", err)
	}
}
